function plotsmn3(lkld,options)
%
% Usage: plotsmn3(lkld,options)
%       
%    e.g. 
%      plotsmn3(lkld,options);
%
% 	lkld 	: [.1 .2 .7 .3 .3 .4]
%
% 	options is a struct with the following fields
%		idx : [1 2 7 10 78 79]		(shows err plot)
%		err : 0 			(hide err plot)
%             color : [0.7000 0.7000 0.7000]
% 	     labels : {'art','war','royalty','dice','elephant','frog'}
%	    txt_loc : [  0  ,  0  ,    1    ,  1   ,     0    ,  0   ]
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[r,c]=size(lkld);
if (nargin > 1),
	% extract a sample set to compute avg lkld/smn
	if isfield(options,'idx'),
		smn=lkld(options.idx,:);
		if (length(options.idx) > 1),
			show_err=1;
			err=std(smn).^2;
			avg=mean(smn);
		else
			show_err=0;
			avg=smn;
		end;
	else
		smn=lkld;
		if (r > 1),
			show_err=1;
			err=std(smn).^2;
			avg=mean(smn);
		else
			show_err=0;
			avg=smn;
		end;
	end;

	% default color
	if ~isfield(options,'color'),
		options.color = [.5,.5,.5];
	end


	% show error bars
	if isfield(options,'err'),
		show_err = 1;
		y_upper = min(1,max(avg+2*err));
	end

	if show_err,
		y_upper = min(1,max(avg+2*err));
	else
		%show_err = 0;
		y_upper = min(1,max(avg)+min(avg));
	end

	% default labels
	if ~isfield(options,'labels'),
%		options.labels = (1:length(avg));
%		options.txt_loc = zeros(1,length(avg));
	else
		if ~isfield(options,'txt_loc'),
			options.txt_loc = zeros(1,length(avg));
		end
	end
else
	if (size(lkld,1) > 1),
		show_err = 1;
		err=std(lkld).^2;
		avg=mean(lkld);
		y_upper = min(1,max(avg+2*err));
	else
		show_err = 0;
		avg=lkld;
		y_upper = min(1,max(avg)+min(avg));
	end
	options.color = [.5,.5,.5];
end;

colormap(options.color);

% plot SMN
dim = size(avg, 2);
bar(1:dim,avg);
xlim([0 dim+1])
if (show_err),
	hold on; 
	errorbar(avg,err,'r.:','LineWidth',2);
end;

% display custom labels
if (nargin>1 && isfield(options,'labels')),
   % remove x-axis labels
   set(gca, 'Xtick', []);
   % (1) less than 45 classes
   if (length(avg) <= 45)
	for i = 1:dim,
		xpos = i + .05;
		%xpos = i + 0.1;
		ypos = avg(i) + 0.04;
		%ypos = avg(i) + 0.008;
	        if (options.txt_loc(i)),
	            % position text on top of the vertical bar
	    		text(xpos, ypos, options.labels(i), 'Rotation', 90, 'FontSize', 16, 'FontWeight', 'Bold');
	        else
	            % position text next to horizontal axis
	    		text(xpos, 0.03, options.labels(i), 'Rotation', 90, 'FontSize', 16, 'FontWeight', 'Bold');
	    		%text(xpos, 0.008, options.labels(i), 'Rotation', 90, 'FontSize', 16, 'FontWeight', 'Bold');
	        end
	end
   % (2) more than 45 classes
   % NOT TESTED YET
   else
	dim = size(lkld, 2);
	l = lkld(id,:);
	l = toP(l);
	bar(1:dim,l);
	m = max(l);
	axis([0 dim+1 0 m * 1.1])
	[lsort lid] = sort(l,2);
	step = m * 1.1 / 12;
	ypos = m * 1.1;
	for i = lid(end:-1:end - 5)
		xpos = i + 0.5;
		ypos = l(i); %ypos - step; 
		text(xpos, ypos, annotations(i), 'Color', 'r', 'FontSize', 18, 'FontWeight', 'Bold');
	end
   end

end

% final plot details
if (nargin > 1),
   if isfield(options,'xlabel'),
	%xlabel('Semantic Concepts', 'FontSize', 16, 'FontWeight', 'Bold');
	xlabel(options.xlabel, 'FontSize', 16, 'FontWeight', 'Bold');
   end
end
%ylabel('Probabilities', 'FontSize', 16, 'FontWeight', 'Bold');
ylim([0 y_upper]);
grid on;
set(gca,'XGrid','off')

