function [R,fval,exitflag,output,lambda] = risop2(aux,data)
%Computes REGULARIZATION operator based on (data,aux)
% Usage:
%   [R,fval,exitflag,output,lambda] = risop2(aux,data,options)
%
%     inputs
%   	aux: clean class-posteriors (1 sample per line)
%      data: noisy class-posteriors (1 sample per line)
%
%    outputs
%	  R: REGULARIZATION operator (that transforms data->aux)
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% some (configurable) options
   delt=0;
   % depending on your matlab version you might have to use one or the other
   qp_opts = optimset('Algorithm','active-set','Display','off','Diagnostics','off','MaxIter',3000,'LargeScale','off');
   %qp_opts = optimset('Algorithm','interior-point-convex','Display','off','Diagnostics','off','MaxIter',3000,'LargeScale','off');

   verb=1;

%%------------------------------------------------
% compute the regularization operator

dim1_R=size(data,2);
dim2_R=size(aux,2);
R=zeros(dim1_R,dim2_R);

% QP -------------------
   [b,A]=toVector(aux,data);
   H=full(A'*A);
   [Hchol,p]=chol(H);
   if (p == 0), 
	if verb,
		fprintf('Quadratic term matrix is PD,');
	end
   else assert(0 == 1,'ERR: unable to continue. Matrix is not positive definite.');
   end
   f=full(-b'*A);
   % inequality constraints
   Aineq=-A;
   bineq=zeros(size(A,1),1);
   % equality constraints
   Aeq=repmat(data,[1 dim2_R]);
   beq=ones(size(data,1),1);
   % solutions upper&lower limits
   lb= []; 
   ub= []; 
   % initial guess
   x0= []; 

   if verb,
	fprintf(' computing Reg. operator... ');
   end;
   % solve QP problem
   [x,fval,exitflag,output,lambda] = quadprog(H,f,full(Aineq),full(bineq),full(Aeq),full(beq),lb,ub,x0,qp_opts);
   if verb,
	fprintf('f(x)=%2.4f (exit flag=%d)\n',fval,exitflag);
   end;

   [Xmtx,foo]=toMatrix(x,[],dim1_R,dim2_R);
   R=Xmtx';


%------------------------------------------------------------------------------------------------
