function [newb,newA]=toVector(B,A)
%
% [new_b,new_A]=toVector(B,A)
%
%   Vectorizes a problem of the type AX=B, where A,X 
%   and B are matrices.
%
%   new_b is equal to rows of B:
%   (transposed and piled one after the other)
%
%   B= [ 1 2       new_b= [ 1 2 3 4 5 6 ]'
%	 3 4 
%	 5 6 ]
%
%   A= [ 1 2	   new_A= [ 1 2 0 0
%	 3 4 ]             0 0 1 2
%			   3 4 0 0
%			   0 0 3 4 ]
%
% e.g. 
%	b=toVector([1 2; 3 4; 5 6]);
%	b=[1 2 3 4 5 6]'
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if (nargin == 1), A=[]; end;
newb=[];
newA=[];


if ~isempty(B)
   [nB,cB]=size(B);
   newb=zeros(nB*cB,1);
   idx=1;
   for i=1:nB,
      for j=1:cB,
	 newb(idx)=B(i,j);
	 idx=idx+1;
      end
   end
end


if ~isempty(A)
   [nA,cA]=size(A);
   if isempty(B),
	newA=sparse(zeros(nA*cA,cA*cA));
	repetitions_per_line=cA;
   else,
	newA=sparse(zeros(nA*cB,cA*cB));
	repetitions_per_line=cB;
   end;
   idx_i=1;
   for i=1:nA,
      idx_j=1;
      for j=1:repetitions_per_line,
	newA(idx_i,idx_j:idx_j+cA-1)=A(i,:);
	idx_i=idx_i+1;
	idx_j=j*cA+1;
      end
   end
end


